pub struct BTreeGraph(/* private fields */);Expand description
A mutable RandomAccessGraph implementation based on a vector of
BTreeMap.
This implementation is slower and uses more resources than a VecGraph,
but it is more flexible as arcs can be added in any order.
By setting the feature serde, this struct can be serialized and
deserialized using serde.
Implementation Notes
This is just a newtype for a LabeledBTreeGraph with
() labels. All
mutation methods are delegated.
Implementations
Sourceimpl BTreeGraph
impl BTreeGraph
Sourcepub fn add_node(&mut self, node: usize) -> bool
pub fn add_node(&mut self, node: usize) -> bool
Add an isolated node to the graph and return true if it is a new node.
Sourcepub fn add_arc(&mut self, u: usize, v: usize) -> bool
pub fn add_arc(&mut self, u: usize, v: usize) -> bool
Add an arc to the graph and return whether it is a new one.
Sourcepub fn add_lender<I: IntoLender>(&mut self, iter_nodes: I) -> &mut Self
pub fn add_lender<I: IntoLender>(&mut self, iter_nodes: I) -> &mut Self
Add nodes and successors from an IntoLender yielding a
NodeLabelsLender.
Sourcepub fn from_lender<I: IntoLender>(iter_nodes: I) -> Self
pub fn from_lender<I: IntoLender>(iter_nodes: I) -> Self
Creates a new graph from an IntoLender yielding a
NodeLabelsLender.
Sourcepub fn add_arcs(&mut self, arcs: impl IntoIterator<Item = (usize, usize)>)
pub fn add_arcs(&mut self, arcs: impl IntoIterator<Item = (usize, usize)>)
Add arcs from an IntoIterator, adding new nodes as needed.
The items must be pairs of the form (usize, usize) specifying an arc.
Sourcepub fn from_arcs(arcs: impl IntoIterator<Item = (usize, usize)>) -> Self
pub fn from_arcs(arcs: impl IntoIterator<Item = (usize, usize)>) -> Self
Creates a new graph from an IntoIterator.
The items must be pairs of the form (usize, usize) specifying
an arc.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)