ConstCodesDecoderFactory

Struct ConstCodesDecoderFactory 

pub struct ConstCodesDecoderFactory<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets, const OUTDEGREES: usize = { code_consts::GAMMA }, const REFERENCES: usize = { code_consts::UNARY }, const BLOCKS: usize = { code_consts::GAMMA }, const INTERVALS: usize = { code_consts::GAMMA }, const RESIDUALS: usize = { code_consts::ZETA3 }> { /* private fields */ }

Implementations

Source

impl<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets, const OUTDEGREES: usize, const REFERENCES: usize, const BLOCKS: usize, const INTERVALS: usize, const RESIDUALS: usize> ConstCodesDecoderFactory<E, F, OFF, OUTDEGREES, REFERENCES, BLOCKS, INTERVALS, RESIDUALS>

pub fn offsets_to_slice( self, ) -> ConstCodesDecoderFactory<E, F, Owned<Box<[usize]>>, OUTDEGREES, REFERENCES, BLOCKS, INTERVALS, RESIDUALS>

Remaps the offsets in a slice of usize.

This method is mainly useful for benchmarking and testing purposes, as representing the offsets as a slice increasing significantly the memory footprint.

This method is used by BvGraph::offsets_to_slice.

Source

impl<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets, const OUTDEGREES: usize, const REFERENCES: usize, const BLOCKS: usize, const INTERVALS: usize, const RESIDUALS: usize> ConstCodesDecoderFactory<E, F, OFF, OUTDEGREES, REFERENCES, BLOCKS, INTERVALS, RESIDUALS>

pub fn new( factory: F, offsets: MemCase<OFF>, comp_flags: CompFlags, ) -> Result<Self>

Creates a new builder from the given data and compression flags.