pub struct File {}Expand description
The graph is read from a file; offsets are fully deserialized in memory.
Note that you must guarantee that the graph file is padded with enough
zeroes so that it can be read one u32 at a time.