LoadMode

Trait LoadMode 

pub trait LoadMode: 'static + Sealed {
    type Factory<E: Endianness>;
    type Offsets: Offsets;

    // Required methods
    fn new_factory<E: Endianness, P: AsRef<Path>>(
        graph: P,
        flags: MemoryFlags,
    ) -> Result<Self::Factory<E>>;
    fn load_offsets<P: AsRef<Path>>(
        offsets: P,
        flags: MemoryFlags,
    ) -> Result<MemCase<Self::Offsets>>;
}
Load mode.

The load mode is the way the graph data is accessed. Each load mode has a corresponding strategy to access the graph and the offsets.

You can set both modes with LoadConfig::mode, or set them separately with LoadConfig::graph_mode and LoadConfig::offsets_mode.

Required Associated Types

Required Methods

fn new_factory<E: Endianness, P: AsRef<Path>>( graph: P, flags: MemoryFlags, ) -> Result<Self::Factory<E>>

fn load_offsets<P: AsRef<Path>>( offsets: P, flags: MemoryFlags, ) -> Result<MemCase<Self::Offsets>>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors