Offsets

Trait Offsets 

pub trait Offsets: for<'a> DeserInner<DeserType<'a>: IndexedSeq<Input = usize, Output<'a> = usize>> { }
Compound trait expressing the trait bounds for offsets.

See the MemCase documentation for an explanation as to why we bound first with DeserInner and then require the bound we are interested in on the associated deserialization type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: for<'a> DeserInner<DeserType<'a>: IndexedSeq<Input = usize, Output<'a> = usize>>> Offsets for T