CsrSortedGraph

Struct CsrSortedGraph 

pub struct CsrSortedGraph<DCF = Box<[usize]>, S = Box<[usize]>>(/* private fields */);
A wrapper for a CsrGraph with the additional guarantee that the successors are sorted.

Implementations

Source

impl CsrSortedGraph

pub fn from_lender<I: IntoLender>(iter_nodes: I) -> Self
where I::Lender: for<'next> NodeLabelsLender<'next, Label = usize> + SortedLender, for<'succ> LenderIntoIter<'succ, I::Lender>: SortedIterator,

Creates a new sorted CSR graph from an IntoLender yielding a sorted NodeLabelsLender with sorted successors.

pub fn from_seq_graph<G: SequentialGraph>(g: &G) -> Self
where for<'a> G::Lender<'a>: SortedLender, for<'a, 'b> LenderIntoIter<'b, G::Lender<'a>>: SortedIterator,

Creates a new sorted CSR graph from a SequentialGraph with sorted lenders and sorted successors.

Source

impl CsrSortedGraph<EliasFano<SelectAdaptConst<BitVec<Box<[usize]>>, Box<[usize]>, 12, 4>>, BitFieldVec>

pub fn try_from_graph<G: SequentialGraph>(g: &G) -> Result<Self>
where for<'a> G::Lender<'a>: SortedLender, for<'a, 'b> LenderIntoIter<'b, G::Lender<'a>>: SortedIterator,

Creates a new compressed CSR sorted graph from a sequential graph with sorted lender, sorted successors, and providing the number of arcs.

This method will return an error if the graph does not provide the number of arcs.