PermutedGraph

Struct PermutedGraph 

pub struct PermutedGraph<'a, G: SequentialGraph, P: SliceByValue<Value = usize> + ?Sized> {
    pub graph: &'a G,
    pub perm: &'a P,
}
A wrapper applying a permutation to the iterators of an underlying graph.

Note that nodes are simply remapped: thus, neither the iterator on the graph nor the successors are sorted.

Fields

graph: &'a G

The underlying graph.

perm: &'a P

The permutation to apply: node i of the permuted graph corresponds to node perm[i] of the underlying graph.