Module lenders

Module lenders 

The main iteration trait, convenience types and associated implementations.

The implementations in this module have the effect that most of the methods of a Lender (e.g., lender::Map) will return a NodeLabelsLender when applied to a NodeLabelsLender. Without the implementations, one would obtain a normal Lender, which would not be usable as an argument, say, of BvComp::extend.

Structs

IntoLabeledPairs
An Iterator adapter that converts a NodeLabelsLender into an iterator of labeled pairs.
IntoPairs
An Iterator adapter that converts a NodeLabelsLender into an iterator of pairs.

Traits

NodeLabelsLender
Iteration on nodes and associated labels.

Type Aliases

LenderIntoIter
Convenience type alias for the Iterator returned by the IntoIterator associated type of a NodeLabelsLender.
LenderIntoIterator
Convenience type alias for the associated type IntoIterator of a NodeLabelsLender.
LenderLabel
Convenience type alias for the associated type Label of a NodeLabelsLender.