pub type LenderLabel<'lend, L> = <L as NodeLabelsLender<'lend>>::Label;Expand description
Convenience type alias for the associated type Label of a NodeLabelsLender.
pub type LenderLabel<'lend, L> = <L as NodeLabelsLender<'lend>>::Label;Convenience type alias for the associated type Label of a NodeLabelsLender.