BitDeserializer

Trait BitDeserializer 

pub trait BitDeserializer<E: Endianness, BR: BitRead<E>> {
    type DeserType;

    // Required method
    fn deserialize(
        &self,
        bitstream: &mut BR,
    ) -> Result<Self::DeserType, BR::Error>;
}
A trait for types implementing logic for deserializing another type from a bitstream with code-reading capabilities.

Required Associated Types

type DeserType

The type that implementations of this trait can deserialize.

Required Methods

fn deserialize(&self, bitstream: &mut BR) -> Result<Self::DeserType, BR::Error>

Deserializes the given value from a BitRead.

Implementations on Foreign Types

Source

impl<E: Endianness, BR: BitRead<E>> BitDeserializer<E, BR> for ()

No-op implementation of BitDeserializer for ().

Source

type DeserType = ()

Source

fn deserialize(&self, _bitstream: &mut BR) -> Result<Self::DeserType, BR::Error>

Implementors