transpose

Function transpose 

pub fn transpose(
    graph: impl SequentialGraph,
    memory_usage: MemoryUsage,
) -> Result<Left<ArcListGraph<KMergeIters<CodecIter<DefaultBatchCodec>, ()>>>>
Returns the transpose of the provided graph as a sequential graph.

For the meaning of the additional parameter, see SortPairs.