transpose_split

Function transpose_split 

pub fn transpose_split<'graph, G: 'graph + SequentialGraph + for<'a> SplitLabeling<SplitLender<'a>: for<'b> NodeLabelsLender<'b, Label = usize, IntoIterator: IntoIterator<IntoIter: Send + Sync>> + Send + Sync, IntoIterator<'a>: IntoIterator<IntoIter: Send + Sync>>>(
    graph: &'graph G,
    memory_usage: MemoryUsage,
) -> Result<SplitIters<impl IntoIterator<Item = (usize, usize), IntoIter: Send + Sync> + use<'graph, G>>>
Returns a SplitIters structure representing the transpose of the provided splittable graph.

The SplitIters structure can easily converted into a vector of (node, lender) pairs using this From implementation.

For the meaning of the additional parameters, see SortPairs.