Module par_sort_iters

Module par_sort_iters 

Facilities to sort in parallel externally (labelled) pairs of nodes returned by a sequence of iterators.

The typical use of ParSortIters is to sort (labelled) pairs of nodes representing a (labelled) graph; the resulting SplitIters structure can be then used to build a compressed representation of the graph using, for example, BvCompConfig::par_comp_lenders.

For example, when transposing or permuting a splittable graph one obtains such a sequence of iterators.

If your pairs are emitted by a single parallel iterator, consider using ParSortPairs instead.

Structs

ParSortIters
Takes a sequence of iterators of (labelled)pairs as input, and turns them into SplitIters structure which is suitable for BvCompConfig::par_comp_lenders.