Module par_sort_pairs

Module par_sort_pairs 

Facilities to sort in parallel externally (labelled) pairs of nodes returned by a ParallelIterator, returning a SplitIters structure.

The typical use of ParSortPairs is to sort (labelled) pairs of nodes representing a (labelled) graph; the resulting SplitIters structure can be then used to build a compressed representation of the graph using, for example, BvCompConfig::par_comp_lenders.

For example, when reading a graph from a file containing an arc list one typically is able to produce a parallel iterator of (labelled) pairs of nodes.

If your pairs are emitted by a sequence of sequential iterators, consider using ParSortIters instead.

Structs

ParSortPairs
Takes a parallel iterator of (labelled) pairs as input, and turns them into a SplitIters structure which is suitable for BvCompConfig::par_comp_lenders.