pub struct BvGraph<F> { /* private fields */ }Expand description
A random-access graph in the BV format.
The graph depends on a RandomAccessDecoderFactory that can be used to
create decoders for the graph. This allows to decouple the graph from the
underlying storage format, and to use different storage formats for the same
graph. For example, one can use a memory-mapped file for the graph, or load
it in memory, or even generate it on the fly.
Note that the knowledge of the codes used by the graph is in the factory, which provides methods to read each component of the BV format (outdegree, reference offset, block count, etc.), whereas the knowledge of the compression parameters (compression window and minimum interval length) is in this structure.
Implementations
Sourceimpl BvGraph<()>
impl BvGraph<()>
Sourcepub fn with_basename(
basename: impl AsRef<Path>,
) -> LoadConfig<BE, Random, Dynamic, Mmap, Mmap>
pub fn with_basename( basename: impl AsRef<Path>, ) -> LoadConfig<BE, Random, Dynamic, Mmap, Mmap>
Returns a load configuration that can be customized.
Sourceimpl<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets> BvGraph<DynCodesDecoderFactory<E, F, OFF>>
impl<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets> BvGraph<DynCodesDecoderFactory<E, F, OFF>>
Sourcepub fn offsets_to_slice(
self,
) -> BvGraph<DynCodesDecoderFactory<E, F, Owned<Box<[usize]>>>>
pub fn offsets_to_slice( self, ) -> BvGraph<DynCodesDecoderFactory<E, F, Owned<Box<[usize]>>>>
Remaps the offsets in a slice of usize.
This method is mainly useful for benchmarking and testing purposes, as
representing the offsets as a slice increasing significantly the
memory footprint. It just replaces current decoder factory with
the result of DynCodesDecoderFactory::offsets_to_slice.
Sourceimpl<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets> BvGraph<ConstCodesDecoderFactory<E, F, OFF>>
impl<E: Endianness, F: CodesReaderFactoryHelper<E>, OFF: Offsets> BvGraph<ConstCodesDecoderFactory<E, F, OFF>>
Sourcepub fn offsets_to_slice(
self,
) -> BvGraph<ConstCodesDecoderFactory<E, F, Owned<Box<[usize]>>>>
pub fn offsets_to_slice( self, ) -> BvGraph<ConstCodesDecoderFactory<E, F, Owned<Box<[usize]>>>>
Remaps the offsets in a slice of usize.
This method is mainly useful for benchmarking and testing purposes, as
representing the offsets as a slice increasing significantly the
memory footprint. It just replaces current decoder factory with
the result of ConstCodesDecoderFactory::offsets_to_slice.
Sourceimpl<F> BvGraph<F>where
F: RandomAccessDecoderFactory,
impl<F> BvGraph<F>where
F: RandomAccessDecoderFactory,
Sourcepub fn new(
factory: F,
number_of_nodes: usize,
number_of_arcs: u64,
compression_window: usize,
min_interval_length: usize,
) -> Self
pub fn new( factory: F, number_of_nodes: usize, number_of_arcs: u64, compression_window: usize, min_interval_length: usize, ) -> Self
Creates a new BvGraph from the given parameters.
Arguments
reader_factory: backend that can create objects that allows us to read the bitstream of the graph to decode the edges.offsets: the bit offset at which we will have to start for decoding the edges of each node. (This is needed for the random accesses,BvGraphSeqdoes not need them)min_interval_length: the minimum size of the intervals we are going to decode.compression_window: the maximum distance between two nodes that reference each other.number_of_nodes: the number of nodes in the graph.number_of_arcs: the number of arcs in the graph.
Sourcepub fn into_inner(self) -> F
pub fn into_inner(self) -> F
Consumes self and returns the factory.
Sourceimpl<F: SequentialDecoderFactory> BvGraph<F>
impl<F: SequentialDecoderFactory> BvGraph<F>
Sourcepub fn offset_deg_iter(&self) -> OffsetDegIter<F::Decoder<'_>> ⓘ
pub fn offset_deg_iter(&self) -> OffsetDegIter<F::Decoder<'_>> ⓘ
Creates an iterator specialized in the degrees of the nodes. This is slightly faster because it can avoid decoding some of the nodes and completely skip the merging step.
Sourceimpl<F: RandomAccessDecoderFactory> BvGraph<F>
impl<F: RandomAccessDecoderFactory> BvGraph<F>
Sourcepub fn offset_deg_iter_from(&self, node: usize) -> OffsetDegIter<F::Decoder<'_>> ⓘ
pub fn offset_deg_iter_from(&self, node: usize) -> OffsetDegIter<F::Decoder<'_>> ⓘ
Creates an iterator specialized in the degrees of the nodes starting from a given node.