pub struct Zip<L: SequentialLabeling, R: SequentialLabeling>(pub L, pub R);Expand description
Zips together two labelings.
A wrapper tuple struct that zips together two labelings, and provides in return a labeling on pairs. It can be used simply to combine labelings over the same graph, but, more importantly, to attach a labeling to a graph, obtaining a labeled graph. Depending on the traits implemented by the two component labelings, the resulting labeling will be sequential or random-access.
Note that the two labelings should be on the same graph: a debug_assert!
will check if two sequential iterators have the same length and return nodes in the
same order, but no such check is possible for labels as we use Iterator::zip,
which does not perform length checks. For extra safety, consider using
Zip::verify to perform a complete scan of the two labelings.
Tuple Fields
0: L1: RImplementations
Sourceimpl<L: SequentialLabeling, R: SequentialLabeling> Zip<L, R>
impl<L: SequentialLabeling, R: SequentialLabeling> Zip<L, R>
Sourcepub fn verify(&self) -> bool
pub fn verify(&self) -> bool
Performs a complete scan of the content of the two component labelings, returning true if they are compatible, that is, their iterators have the same length and return nodes in the same order, and the two iterators paired to each node return the same number of elements.