pub trait SequentialGraph: SequentialLabeling<Label = usize> { }Expand description
A graph that can be accessed sequentially.
Note that there is no guarantee that the iterator will return nodes in
ascending order, or the successors of a node will be returned in ascending
order. The marker traits SortedLender and SortedIterator can be used
to force these properties.
The function eq can be used to check whether two
graphs are equal.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.