The main iteration trait, convenience types and associated implementations.
The implementations in this module have the effect that most of the methods
of a Lender (e.g., lender::Map) will return a NodeLabelsLender
when applied to a NodeLabelsLender. Without the implementations, one
would obtain a normal Lender, which would not be usable as an argument,
say, of BvComp::extend.
Structs
- Into
Labeled Pairs - An
Iteratoradapter that converts aNodeLabelsLenderinto an iterator of labeled pairs. - Into
Pairs - An
Iteratoradapter that converts aNodeLabelsLenderinto an iterator of pairs.
Traits
- Node
Labels Lender - Iteration on nodes and associated labels.
Type Aliases
- Lender
Into Iter - Convenience type alias for the
Iteratorreturned by theIntoIteratorassociated type of aNodeLabelsLender. - Lender
Into Iterator - Convenience type alias for the associated type
IntoIteratorof aNodeLabelsLender. - Lender
Label - Convenience type alias for the associated type
Labelof aNodeLabelsLender.